@@ -2,7 +2,7 @@ fpcad <-
 function(xf, gaussiand=TRUE, kern = NULL, windowh=NULL,
 			normed=TRUE, centered=FALSE, data.centered=FALSE, data.scaled=FALSE, 
       common.variance=FALSE, nb.factors=3, nb.values=10, sub.title="",
-			plot.eigen=TRUE, plot.score=FALSE, nscore=1:3, filename=NULL)
+			plot.eigen=TRUE, plot.score=FALSE, nscore=1:3, group.name="group", filename=NULL)
 {
 #require(e1071)
 
@@ -15,7 +15,7 @@ if (!is.folder(xf)){
 if (!attr(xf, "same.cols")){
   stop("fpcad applies to an object of class 'folder' in which the data frames have the same column names.")
 }
-x <- as.data.frame(xf)
+x <- as.data.frame(xf, group.name = group.name)
 
 # p denotes the dimension of the data
 p<-ncol(x)-1;
